-- Device [Device]
create table "APP"."DEVICE" (
   "OID"  integer  not null,
   "DEVICE_ID"  varchar(255),
   "NOTIFICATION_DEVICE_ID"  varchar(255),
   "MODEL"  varchar(255),
   "PLATFORM"  varchar(255),
   "PLATFORM_VERSION"  varchar(255),
   "BROWSER"  varchar(255),
  primary key ("OID")
);


-- User [User]
create table "APP"."USER" (
   "USER_ID"  varchar(255)  not null,
   "SECRET_KEY"  varchar(255),
  primary key ("USER_ID")
);


-- Authorized Grant Type [authAgt]
create table "APP"."AUTHORIZED_GRANT_TYPE" (
   "OID"  integer  not null,
   "NAME"  varchar(255),
  primary key ("OID")
);


-- Application [authApl]
create table "APP"."APPLICATION" (
   "APP_ID"  varchar(255)  not null,
   "REFRESH_TOKEN_VALIDITY"  integer,
   "ACCESS_TOKEN_VALIDITY"  integer,
   "AUTHORITIES"  varchar(255),
   "SECRET"  varchar(255),
   "DESCRIPTION"  varchar(255),
   "NAME"  varchar(255),
   "TYPE"  varchar(255),
  primary key ("APP_ID")
);


-- Approval [authApv]
create table "APP"."APPROVAL" (
   "UPDATED_AT"  timestamp,
   "EXPIRATION_DATE"  timestamp,
   "STATUS"  varchar(255),
   "SCOPE"  varchar(255),
   "OID"  integer  not null,
  primary key ("OID")
);


-- Claim [authClaim]
create table "APP"."CLAIM" (
   "OID"  integer  not null,
   "KEY"  varchar(255),
   "VALUE"  varchar(255),
  primary key ("OID")
);


-- Code [authCod]
create table "APP"."CODE" (
   "CODE"  varchar(255)  not null,
   "AUTHENTICATION"  varchar(255),
   "AUTHENTICATIONBLOB" blob,
   "CREATION_DATE"  timestamp,
  primary key ("CODE")
);

-- Redirect Uri [authUri]
create table "APP"."REDIRECT_URI" (
   "OID"  integer  not null,
   "URL"  varchar(255),
  primary key ("OID")
);

-- Identity [authIdy]
create table "APP"."IDENTITY" (
   "EXPIRED"  smallint,
   "LOCKED"  smallint,
   "PASSWORD"  varchar(255),
   "USER_ID"  varchar(255)  not null,
   "DISABLED"  smallint,
   "ATTEMPTS_NUMBER"  integer,
   "PASSWORD_EXPIRATION_DATE"  timestamp,
   "EMAIL"  varchar(255),
   "AUTH_ADMIN"  smallint,
   "FIRST_NAME"  varchar(255),
   "LAST_NAME"  varchar(255),
  primary key ("USER_ID")
);


-- Refresh Token [authRft]
create table "APP"."REFRESH_TOKEN" (
   "OID"  integer  not null,
   "TOKEN"  varchar(3500),
   "EXPIRATION_DATE"  timestamp,
  primary key ("OID")
);


-- Authorized Resource [authRsc]
create table "APP"."AUTHORIZED_RESOURCE" (
   "OID"  integer  not null,
   "NAME"  varchar(255),
  primary key ("OID")
);


-- Scope [authScp]
create table "APP"."SCOPE" (
   "OID"  integer  not null,
   "AUTO_APPROVE"  smallint,
   "NAME"  varchar(255),
  primary key ("OID")
);


-- To Do [cls1]
create table "APP"."TO_DO" (
   "OID"  integer  not null,
   "NOTES"  clob(10000),
   "END_TIME"  time,
   "END_DATE"  date,
   "START_TIME"  time,
   "START_DATE"  date,
   "LOCATION"  varchar(255),
   "TITLE"  varchar(255),
  primary key ("OID")
);


-- User_To Do [as1]
alter table "APP"."TO_DO"  add column  "USER_USER_ID"  varchar(255);
alter table "APP"."TO_DO"   add constraint FK_TO_DO_USER foreign key ("USER_USER_ID") references "APP"."USER" ("USER_ID");


-- AuthorizedGrantType_Application [authAgt_Apl]
alter table "APP"."AUTHORIZED_GRANT_TYPE"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."AUTHORIZED_GRANT_TYPE"   add constraint FK_AUTHORIZED_GRANT_TYPE_APPLI foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- Approval_Application [authApv_Apl]
alter table "APP"."APPROVAL"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."APPROVAL"   add constraint FK_APPROVAL_APPLICATION foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- Approval_Identity [authApv_Idy]
alter table "APP"."APPROVAL"  add column  "IDENTITY_USER_ID"  varchar(255);
alter table "APP"."APPROVAL"   add constraint FK_APPROVAL_IDENTITY foreign key ("IDENTITY_USER_ID") references "APP"."IDENTITY" ("USER_ID");


-- Claim_Identity [authClaim_Idy]
create table "APP"."CLAIM_IDENTITY" (
   "CLAIM_OID"  integer not null,
   "IDENTITY_USER_ID"  varchar(255) not null,
  primary key ("CLAIM_OID", "IDENTITY_USER_ID")
);
alter table "APP"."CLAIM_IDENTITY"   add constraint FK_CLAIM_IDENTITY_CLAIM foreign key ("CLAIM_OID") references "APP"."CLAIM" ("OID");
alter table "APP"."CLAIM_IDENTITY"   add constraint FK_CLAIM_IDENTITY_IDENTITY foreign key ("IDENTITY_USER_ID") references "APP"."IDENTITY" ("USER_ID");


-- Device_Application [authDevice_Apl]
alter table "APP"."DEVICE"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."DEVICE"   add constraint FK_DEVICE_APPLICATION foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- Device_Identity [authDevice_Idy]
alter table "APP"."DEVICE"  add column  "USER_USER_ID"  varchar(255);
alter table "APP"."DEVICE"   add constraint FK_DEVICE_IDENTITY foreign key ("USER_USER_ID") references "APP"."IDENTITY" ("USER_ID");


-- RefreshToken_Application [authRft_Apl]
alter table "APP"."REFRESH_TOKEN"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."REFRESH_TOKEN"   add constraint FK_REFRESH_TOKEN_APPLICATION foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- RefreshToken_Identity [authRft_Idy]
alter table "APP"."REFRESH_TOKEN"  add column  "IDENTITY_USER_ID"  varchar(255);
alter table "APP"."REFRESH_TOKEN"   add constraint FK_REFRESH_TOKEN_IDENTITY foreign key ("IDENTITY_USER_ID") references "APP"."IDENTITY" ("USER_ID");


-- AuthorizedResource_Application [authRsc_Apl]
alter table "APP"."AUTHORIZED_RESOURCE"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."AUTHORIZED_RESOURCE"   add constraint FK_AUTHORIZED_RESOURCE_APPLICA foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- Scope_Application [authScp_Apl]
alter table "APP"."SCOPE"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."SCOPE"   add constraint FK_SCOPE_APPLICATION foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");

-- RedirectUri_Application [authUri_Apl]
alter table "APP"."REDIRECT_URI"  add column  "APPLICATION_APP_ID"  varchar(255);
alter table "APP"."REDIRECT_URI"   add constraint FK_REDIRECT_URI_APPLICATION foreign key ("APPLICATION_APP_ID") references "APP"."APPLICATION" ("APP_ID");


-- Class Services Mapping
create table APP.WR_DELETE_HISTORY(
  OID  integer not null,
  OBJECT_ID varchar(200) not null,
  CLASS_ID varchar(32) not null,
  DELETED_AT timestamp not null,
  primary key (OID));
  
INSERT INTO APP."IDENTITY" (EXPIRED,LOCKED,PASSWORD,USER_ID,DISABLED,ATTEMPTS_NUMBER,PASSWORD_EXPIRATION_DATE,EMAIL,AUTH_ADMIN,FIRST_NAME,LAST_NAME) VALUES (
0,0,'CDQDYubDrvkbju7mw24HFEcDPQKCLea1RbXfWBna9eqoeOvUoOormSTJQShLRgnkGKXIA8bVK8Ww1TFVTSdZH66Dx3s=','admin',0,0,NULL,'wradmin@webratio.com',1,'System','Administrator');
INSERT INTO APP."IDENTITY" (EXPIRED,LOCKED,PASSWORD,USER_ID,DISABLED,ATTEMPTS_NUMBER,PASSWORD_EXPIRATION_DATE,EMAIL,AUTH_ADMIN,FIRST_NAME,LAST_NAME) VALUES (
0,0,'F1UXPuowx8iiUEisDTylTowZJvgDcKuLgOMOYtjlELDLfzexhZYDGuhhmeNP7EOudzwhPoKjPbmdatPIlRYne7De6Tw=','MyToDosUser',0,0,NULL,'MyToDosUser@domain.com',0,'MyToDosUser','');

INSERT INTO APP."USER" (USER_ID,SECRET_KEY) VALUES ('MyToDosUser',NULL);

INSERT INTO APP.APPLICATION (APP_ID,REFRESH_TOKEN_VALIDITY,ACCESS_TOKEN_VALIDITY,AUTHORITIES,SECRET,DESCRIPTION,NAME,"TYPE") VALUES ('OAuth2Administration',31536000,2592000,NULL,'ERyEXhVo2tk6w4AEjJnrQJH2KyhOMVDJuP+NVg2c/vUj4/8SxUDnZM9isdu4bxo4A91vIegWP9AyP0//UFhGSTvUMIc=','The default application to manage identities and client applications','OAuth2 Administration Application','WEB');
INSERT INTO APP.APPLICATION (APP_ID,REFRESH_TOKEN_VALIDITY,ACCESS_TOKEN_VALIDITY,AUTHORITIES,SECRET,DESCRIPTION,NAME,"TYPE") VALUES ('MyToDos',2592000,3600,NULL,'r/06w25Z/VyWTvxXRPfUpqTWILyO2QmRv0nxzBnPLkhzkOOZRzzP5FykRudjsGQLxejnsglJ5jORtxO0actrmuhF/ns=','MyToDos','MyToDos','WEB');

INSERT INTO APP."SCOPE" (OID,AUTO_APPROVE,NAME,APPLICATION_APP_ID) VALUES (1,1,'identity_registration','OAuth2Administration');
INSERT INTO APP."SCOPE" (OID,AUTO_APPROVE,NAME,APPLICATION_APP_ID) VALUES (2,1,'anonymous_user','MyToDos');
INSERT INTO APP."SCOPE" (OID,AUTO_APPROVE,NAME,APPLICATION_APP_ID) VALUES (3,1,'password_change','MyToDos');

INSERT INTO APP.AUTHORIZED_RESOURCE (OID,NAME,APPLICATION_APP_ID) VALUES (1,'TodosManagerService','OAuth2Administration');
INSERT INTO APP.AUTHORIZED_RESOURCE (OID,NAME,APPLICATION_APP_ID) VALUES (2,'oauth2-resource','OAuth2Administration');
INSERT INTO APP.AUTHORIZED_RESOURCE (OID,NAME,APPLICATION_APP_ID) VALUES (3,'oauth2-resource','MyToDos');
INSERT INTO APP.AUTHORIZED_RESOURCE (OID,NAME,APPLICATION_APP_ID) VALUES (4,'TodosManagerService','MyToDos');
INSERT INTO APP.AUTHORIZED_RESOURCE (OID,NAME,APPLICATION_APP_ID) VALUES (5,'MyToDos','MyToDos');

INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (1,'client_credentials','OAuth2Administration');
INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (2,'password','OAuth2Administration');
INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (3,'refresh_token','OAuth2Administration');
INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (4,'client_credentials','MyToDos');
INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (5,'password','MyToDos');
INSERT INTO APP.AUTHORIZED_GRANT_TYPE (OID,NAME,APPLICATION_APP_ID) VALUES (6,'refresh_token','MyToDos');

INSERT INTO APP.APPROVAL (UPDATED_AT,EXPIRATION_DATE,STATUS,"SCOPE",OID,APPLICATION_APP_ID,IDENTITY_USER_ID) VALUES (
NULL,NULL,'APPROVED','identity_registration',1,'OAuth2Administration','admin');
INSERT INTO APP.APPROVAL (UPDATED_AT,EXPIRATION_DATE,STATUS,"SCOPE",OID,APPLICATION_APP_ID,IDENTITY_USER_ID) VALUES (
NULL,NULL,'APPROVED','password_change',2,'MyToDos','MyToDosUser');


INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
1,'Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.','11:00:00','2020-06-10','10:00:00','2020-06-12','Office','My Appointment 1','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
2,'Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.','15:00:00','2020-06-13','16:00:00','2020-06-13','Online','My Appointment 2','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
3,'Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.','12:00:00','2020-06-20','15:00:00','2020-06-20','Home','My Appointment 3','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
5,'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo','17:00:00','2020-06-21','16:00:00','2020-06-21','Online','My Appointment 4','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
6,'Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.','17:00:00','2020-06-21','16:00:00','2020-06-21','Home','My Appointment 5','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
7,'Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem.','17:00:00','2020-06-21','16:00:00','2020-06-21','Online','My Appointment 6','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
8,'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo','13:30:00','2020-06-03','13:00:00','2020-06-03','Online','My Appointment 7','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
9,'Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.','17:30:00','2020-06-01','16:00:00','2020-06-01','Office','My Appointment 8','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
10,'Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem.','09:00:00','2020-06-19','08:00:00','2020-06-19','Office','My Appointment 9','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
11,'Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.','09:30:00','2020-06-16','08:00:00','2020-06-16','Office','My Appointment 10','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
12,'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo','13:30:00','2020-06-18','10:00:00','2020-06-18','Home','My Appointment 11','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
13,'Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.','15:00:00','2020-06-17','10:00:00','2020-06-17','Home','My Appointment 12','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
14,'Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.','19:00:00','2020-06-16','16:00:00','2020-06-16','Home','My Appointment 13','MyToDosUser');
INSERT INTO APP.TO_DO (OID,NOTES,END_TIME,END_DATE,START_TIME,START_DATE,LOCATION,TITLE,USER_USER_ID) VALUES (
15,'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','18:00:00','2020-06-15','17:30:00','2020-06-15','Online','My Appointment 14','MyToDosUser');
  